@@ -142,7 +142,7 @@ module name does not include the ".py" suffix.
 }
         raise error.ConfigurationError(msg)
     except AttributeError, err:
-        logging.exception('An exception occured.')
+        logging.exception('An exception occurred.')
         msg = """AttributeError: %(err)s
 
 Could not find required "Config" class in "%(name)s.py".
@@ -332,14 +332,6 @@ class ConfigFunctionality(object):
             except ImportError:
                 self.chart_options = None
 
-        # "Render As Docbook" requires python-xml.
-        if 'RenderAsDocbook' not in self.actions_excluded:
-            try:
-                from xml.dom.ext.reader import Sax
-            except ImportError:
-                # this will also remove it from the actions menu:
-                self.actions_excluded.append('RenderAsDocbook')
-
         # 'setuid' special auth method auth method can log out
         self.auth_can_logout = ['setuid']
         self.auth_login_inputs = []
@@ -411,6 +403,8 @@ class ConfigFunctionality(object):
         secret_key_names = ['action/cache', 'wikiutil/tickets', 'xmlrpc/ProcessMail', 'xmlrpc/RemoteScript', ]
         if self.jabber_enabled:
             secret_key_names.append('jabberbot')
+        if self.textchas:
+            secret_key_names.append('security/textcha')
 
         secret_min_length = 10
         if isinstance(self.secrets, str):
@@ -785,7 +779,7 @@ options_no_group_name = {
      "Exclude unwanted actions (list of strings)"),
 
     ('allow_xslt', False,
-     "if True, enables XSLT processing via 4Suite (note that this enables anyone with enough know-how to insert '''arbitrary HTML''' into your wiki, which is why it defaults to `False`)"),
+        "if True, enables XSLT processing via 4Suite (Note that this is DANGEROUS. It enables anyone who can edit the wiki to get '''read/write access to your filesystem as the moin process uid/gid''' and to insert '''arbitrary HTML''' into your wiki pages, which is why this setting defaults to `False` (XSLT disabled). Do not set it to other values, except if you know what you do and if you have very trusted editors only)."),
 
     ('password_checker', DefaultExpression('_default_password_checker'),
      'checks whether a password is acceptable (default check is length >= 6, at least 4 different chars, no keyboard sequence, not username used somehow (you can switch this off by using `None`)'),
@@ -817,9 +811,11 @@ options_no_group_name = {
     ('surge_lockout_time', 3600, "time [s] someone gets locked out when ignoring the warnings"),
 
     ('textchas', None,
-     "Spam protection setup using site-specific questions/answers, see HelpOnTextChas."),
+     "Spam protection setup using site-specific questions/answers, see HelpOnSpam."),
     ('textchas_disabled_group', None,
      "Name of a group of trusted users who do not get asked !TextCha questions."),
+    ('textchas_expiry_time', 600,
+     "Time [s] for a !TextCha to expire."),
 
     ('antispam_master_url', "http://master.moinmo.in/?action=xmlrpc2",
      "where antispam security policy fetches spam pattern updates (if it is enabled)"),
@@ -828,7 +824,7 @@ options_no_group_name = {
     # and receive a FORBIDDEN for anything except viewing a page
     # list must not contain 'java' because of twikidraw wanting to save drawing uses this useragent
     ('ua_spiders',
-     ('archiver|cfetch|charlotte|crawler|curl|gigabot|googlebot|heritrix|holmes|htdig|httrack|httpunit|'
+     ('archiver|cfetch|charlotte|crawler|gigabot|googlebot|heritrix|holmes|htdig|httrack|httpunit|'
       'intelix|jeeves|larbin|leech|libwww-perl|linkbot|linkmap|linkwalk|litefinder|mercator|'
       'microsoft.url.control|mirror| mj12bot|msnbot|msrbot|neomo|nutbot|omniexplorer|puf|robot|scooter|seekbot|'
       'sherlock|slurp|sitecheck|snoopy|spider|teleport|twiceler|voilabot|voyager|webreaper|wget|yeti'),
@@ -899,6 +895,7 @@ options_no_group_name = {
      'show section numbers in headings by default'),
     ('show_timings', False, "show some timing values at bottom of a page"),
     ('show_version', False, "show moin's version at the bottom of a page"),
+    ('show_rename_redirect', False, "if True, offer creation of redirect pages when renaming wiki pages"),
 
     ('packagepages_actions_excluded',
      ['setthemename',  # related to questionable theme stuff, see below
@@ -941,7 +938,9 @@ options_no_group_name = {
         'up': ('page_parent_page', {}, _("Up"), "up"),
      },
      "dict of {'iconname': (url, title, icon-img-key), ...}. Available only in classic theme."),
-
+    ('show_highlight_msg', False, "Show message that page has highlighted text "
+                                  "and provide link to non-highlighted "
+                                  "version."),
   )),
   # ==========================================================================
   'editor': ('Editor related', None, (
@@ -953,6 +952,7 @@ options_no_group_name = {
     ('edit_locking', 'warn 10', "Editor locking policy: `None`, `'warn <timeout in minutes>'`, or `'lock <timeout in minutes>'`"),
     ('edit_ticketing', True, None),
     ('edit_rows', 20, "Default height of the edit box"),
+    ('comment_required', False, "if True, only allow saving if a comment is filled in"),
 
   )),
   # ==========================================================================
@@ -1191,7 +1191,7 @@ options = {
       ('checkbox_defaults',
        {
         'mailto_author': 0,
-        'edit_on_doubleclick': 0,
+        'edit_on_doubleclick': 1,
         'remember_last_visit': 0,
         'show_comments': 0,
         'show_nonexist_qm': False,
@@ -1280,6 +1280,57 @@ options = {
       ('include', [], 'List of pathes to backup.'),
       ('exclude', lambda self, filename: False, 'Function f(self, filename) that tells whether a file should be excluded from backup. By default, nothing is excluded.'),
     )),
+    'rss': ('RSS settings',
+        'These settings control RSS behaviour.',
+    (
+      ('items_default', 15, "Default maximum items value for RSS feed. Can be "
+                            "changed via items URL query parameter of rss_rc "
+                            "action."),
+      ('items_limit', 100, "Limit for item count got via RSS (i. e. user "
+                           "can't get more than items_limit items even via "
+                           "changing items URL query parameter)."),
+      ('unique', 0, "If set to 1, for each page name only one RSS item would "
+                    "be shown. Can be changed via unique rss_rc action URL "
+                    "query parameter."),
+      ('diffs', 0, "Add diffs in RSS item descriptions by default. Can be "
+                   "changed via diffs URL query parameter of rss_rc action."),
+      ('ddiffs', 0, "If set to 1, links to diff view instead of page itself "
+                    "would be generated by default. Can be changed via ddiffs "
+                    "URL query parameter of rss_rc action."),
+      ('lines_default', 20, "Default line count limit for diffs added as item "
+                            "descriptions for RSS items. Can be changed via "
+                            "lines URL query parameter of rss_rc action."),
+      ('lines_limit', 100, "Limit for possible line count for diffs added as "
+                           "item descriptions in RSS."),
+      ('show_attachment_entries', 0, "If set to 1, items, related to "
+                                     "attachment management, would be added to "
+                                     "RSS feed. Can be changed via show_att "
+                                     "URL query parameter of rss_rc action."),
+      ('page_filter_pattern', "", "Default page filter pattern for RSS feed. "
+                                  "Empty pattern matches to any page. Pattern "
+                                  "beginning with circumflex is interpreted as "
+                                  "regular expression. Pattern ending with "
+                                  "slash matches page and all its subpages. "
+                                  "Otherwise pattern sets specific pagename. "
+                                  "Can be changed via page URL query parameter "
+                                  "of rss_rc action."),
+      ('show_page_history_link', True, "Add link to page change history "
+                                       "RSS feed in theme."),
+    )),
+    'search_macro': ('Search macro settings',
+        'Settings related to behaviour of search macros (such as FullSearch, '
+        'FullSearchCached, PageList)',
+    (
+      ('parse_args', False, "Do search macro parameter parsing. In previous "
+                            "versions of MoinMoin, whole search macro "
+                            "parameter string had been interpreted as needle. "
+                            "Now, to provide ability to pass additional "
+                            "parameters, this behaviour should be changed."),
+      ('highlight_titles', 1, "Perform title matches highlighting by default "
+                              "in search results generated by macro."),
+      ('highlight_pages', 1, "Add highlight parameter to links in search "
+                             "results generated by search macros by default."),
+    )),
 }
 
 def _add_options_to_defconfig(opts, addgroup=True):
