@@ -63,7 +63,7 @@ except ImportError:
             self.raw = raw
             self.request = request
 
-        def format(self, formatter):
+        def format(self, formatter, **kw):
             _ = self.request.getText
             from MoinMoin.parser.text import Parser as TextParser
             self.request.write(formatter.sysmsg(1) +
@@ -152,7 +152,7 @@ class MoinWriter(html4css1.Writer):
         if current_version < required_version:
             err = 'ERROR: The installed docutils version is %s;' % ('.'.join([str(i) for i in current_version]))
             err += ' version %s or later is required.' % ('.'.join([str(i) for i in required_version]))
-            raise RuntimeError, err
+            raise RuntimeError(err)
 
     def translate(self):
         visitor = MoinTranslator(self.document,
@@ -200,7 +200,7 @@ Lists: * bullets; 1., a. numbered items.
         self.request = request
         self.form = request.form
 
-    def format(self, formatter):
+    def format(self, formatter, **kw):
         # Create our simple parser
         parser = MoinDirectives(self.request)
 
@@ -580,7 +580,7 @@ class MoinDirectives:
         else:
             lines = [_("**Maximum number of allowed includes exceeded**")]
             state_machine.insert_input(lines, 'MoinDirectives')
-            return
+            return []
 
         if len(content):
             pagename = content[0]
@@ -598,7 +598,7 @@ class MoinDirectives:
                     lines = [_("**Could not find the referenced page: %s**") % (pagename, )]
             # Insert the text from the included document and then continue parsing
             state_machine.insert_input(lines, 'MoinDirectives')
-        return
+        return []
 
     include.has_content = include.content = True
     include.option_spec = {}
@@ -623,7 +623,7 @@ class MoinDirectives:
             ref = reference(macro, refuri=macro)
             ref['name'] = macro
             return [ref]
-        return
+        return []
 
     macro.has_content = macro.content = True
     macro.option_spec = {}
